Push

Trait Push 

pub trait Push<K>: KeyedCollection {
    // Required method
    fn push(&mut self, value: Self::Value) -> K;
}
Insert a value into the collection without specifying a key, returning the key that was automatically generated.

Required Methods

fn push(&mut self, value: Self::Value) -> K

Insert a value into the collection without specifying a key, returning the key that was automatically generated.

Implementations on Foreign Types

Source

impl<V> Push<usize> for Vec<V>

Source

fn push(&mut self, value: V) -> usize

Source

impl<V> Push<Index> for Arena<V>

Source

fn push(&mut self, value: V) -> Index

Source

impl<V, C> Push<usize> for StableVecFacade<V, C>
where C: Core<V>,

Source

fn push(&mut self, value: V) -> usize

Implementors

Source

impl<K, C: Push<K, Key = K>> Push<K> for RTreed<C>
where K: Clone, C::Value: Clone + RTreeObject,