pub trait Push<K>: KeyedCollection {
// Required method
fn push(&mut self, value: Self::Value) -> K;
}Expand description
Insert a value into the collection without specifying a key, returning the key that was automatically generated.
pub trait Push<K>: KeyedCollection {
// Required method
fn push(&mut self, value: Self::Value) -> K;
}Insert a value into the collection without specifying a key, returning the key that was automatically generated.